/**
 * Represents a collection of sprites to be drawn to the canvas. Only the active screen is drawn.
 * @class
 * @param {object} args Construction values for public properties.
 */

punx.Screen = function() {

    /**
     * Camera tracking X offset.
     */
    this.track = 0;

    this.bgs = [];

    this.actors = [];

    this.overlays = [];

    var updated = false;

    /**
     * Update all sprites and remember if updated.
     * Called by the {Punx} update loop.
     */
    this.update = function(delta) {
        for (var i in this.bgs) {
            updated |= this.bgs[i].update(delta);
        }
        for (var i in this.actors) {
            updated |= this.actors[i].update(delta);
        }
        for (var i in this.overlays) {
            updated |= this.overlays[i].update(delta);
        }
        return updated;
    };

    /**
     * Draws only if updated.
     * Draws all entities in order.
     * @public
     */
    this.draw = function() {
        if (!updated) return;
        updated = false;
        punx.clear();
        for (var i in this.bgs) {
            this.bgs[i].draw(this.track);
        }
        for (var i in this.actors) {
            this.actors.draw(this.track);
        }
        for (var i in this.overlays) {
            this.overlays[i].draw(this.track);
        }
    };

};

