/**
 * Keyboard interface.
 */
punx.key = new function() {

    /**
     * Object keyed by button name and its current press-state, so that sprites et al. can poll the keyboard.
     * @private
     * @type object<string,boolean>
     */
    var state = {};

    /**
     * Internal map between keyCode and button name.
     * @private
     * @type object<integer,string>
     */
    var map = {
        9:'tab',
        13:'enter',
        27:'escape',
        32:'space',
        37:'left',
        38:'up',
        39:'right',
        40:'down'
    };
    for (var i=48;i<=57;i++) { map[i] = String.fromCharCode(i); } // numbers
    for (var i=97;i<=122;i++) { map[i] = String.fromCharCode(i); } // letters

    this.pressed = function(name) {
        return name in state && state[name];
    };

    /**
     * Document's onkeydown listener, attached to the document by the grid during create().
     * Sets the key's state to true. Keypresses that are combined with special keys like CTRL, ALT, Shift, Meta/Windows, Menu, etc are ignored.
     * @public
     * @param {event} [e=window.event]
     */
    this.onkeydown = function(e) {
        e=e||window.event;
        if (!(e.keyCode in map) || e.altGraphKey || e.metaKey || e.altKey || e.shiftKey || e.ctrlKey) return;
        e.preventDefault();
        e.stopPropagation();
        state[map[e.keyCode]] = true;
    }.bind(this);

    /**
     * Document's keyup listener, attached to the document by the grid during create().
     * Sets the key's state to false.
     * @public
     * @param {event} [e=window.event]
     */
    this.onkeyup = function(e) {
        e=e||window.event;
        if (!(e.keyCode in map)) return;
        e.preventDefault();
        e.stopPropagation();
        state[map[e.keyCode]] = false;
    }.bind(this);

};

